package org.nakedobjects.nos.remote;

import org.nakedobjects.nof.core.conf.Configuration;
import org.nakedobjects.nof.core.system.InstanceFactory;
import org.nakedobjects.nof.core.system.ServerListener;
import org.nakedobjects.nof.core.util.NakedObjectConfiguration;
import org.nakedobjects.nos.remote.command.java.JavaDataFactory;
import org.nakedobjects.nos.remote.command.marshal.CriteriaEncoding;
import org.nakedobjects.nos.remote.command.marshal.Marshaller;
import org.nakedobjects.nos.remote.command.socket.AbstractServerListener;


public abstract class AbstractServerListenerInstaller {

    private Marshaller createEncoder(NakedObjectConfiguration configuration) {
        final Marshaller encoder = new Marshaller();
        encoder.setDataFactory(new JavaDataFactory());

        String[] encoders = configuration.getList(Configuration.ROOT + "criteria.encoders");
        if (encoders == null) {
            encoders = new String[0];
        }
        for (int i = 0; i < encoders.length; i++) {
            CriteriaEncoding encoding = (CriteriaEncoding) InstanceFactory.createInstance(encoders[i], CriteriaEncoding.class);
            encoder.addCriteriaStrategy(encoding);
        }

        return encoder;
    }

    protected abstract AbstractServerListener createListenerInstance();

    public ServerListener createListener(NakedObjectConfiguration configuration) {

        final AbstractServerListener serverListener = createListenerInstance();
        serverListener.setEncoder(createEncoder(configuration));

        return serverListener;
    }
}
