package org.nakedobjects.nos.remote.command.java;

import java.io.Serializable;

import org.nakedobjects.noa.adapter.Oid;
import org.nakedobjects.noa.adapter.Version;
import org.nakedobjects.noa.util.ByteDecoder;
import org.nakedobjects.noa.util.ByteEncoder;
import org.nakedobjects.noa.util.Encodable;
import org.nakedobjects.nof.core.util.ToString;
import org.nakedobjects.nof.reflect.remote.data.Data;
import org.nakedobjects.nof.reflect.remote.data.ObjectData;


public class JavaObjectData implements ObjectData, Encodable, Serializable {
    private static final long serialVersionUID = 1L;
    private Data fieldContent[];
    private final Oid oid;
    private final boolean resolved;
    private final String type;
    private final Version version;

    public JavaObjectData(final Oid oid, final String type, final boolean resolved, final Version version) {
        this.oid = oid;
        this.type = type;
        this.resolved = resolved;
        this.version = version;
    }

    public JavaObjectData(final ByteDecoder decoder) {
        type = decoder.getString();
        oid = (Oid) decoder.getObject();
        version = (Version) decoder.getObject();
        resolved = decoder.getBoolean();
        fieldContent = (Data[]) decoder.getObjects();
    }
    
    public void encode(final ByteEncoder encoder) {
        encoder.add(type);
        encoder.add(oid);
        encoder.add(version);
        encoder.add(resolved);
        encoder.add(fieldContent);
    }
    
    public Data[] getFieldContent() {
        return fieldContent;
    }

    public Oid getOid() {
        return oid;
    }

    public String getType() {
        return type;
    }

    public Version getVersion() {
        return version;
    }

    public boolean hasCompleteData() {
        return resolved;
    }

    public void setFieldContent(final Data[] fieldContent) {
        this.fieldContent = fieldContent;
    }

    public String toString() {
        ToString str = new ToString(this);
        str.append("type", type);
        str.append("oid", oid);
        str.append("version", version);
        str.append(",fields=");
        for (int i = 0; fieldContent != null && i < fieldContent.length; i++) {
            if (i > 0) {
                str.append(";");
            }
            if (fieldContent[i] == null) {
                str.append("null");
            } else {
                String name = fieldContent[i].getClass().getName();
                str.append(name.substring(name.lastIndexOf('.') + 1));
            }
        }
        return str.toString();
    }
}
// Copyright (c) Naked Objects Group Ltd.
