package org.nakedobjects.nos.remote.command.pipe;

import org.apache.log4j.Logger;
import org.nakedobjects.nos.remote.command.Request;
import org.nakedobjects.nos.remote.command.Response;


public class PipedConnection {
    private static final Logger LOG = Logger.getLogger(PipedConnection.class);
    private Request request;
    private Response response;
    private RuntimeException exception;

    public synchronized void setRequest(Request request) {
        this.request = request;
        notify();
    }

    public synchronized Request getRequest() {
        while (request == null) {
            try {
                wait();
            } catch (InterruptedException e) {
                LOG.error("wait (getRequest) interrupted", e);
            }
        }

        Request r = request;
        request = null;
        notify();
        return r;
    }

    public synchronized void setResponse(Response response) {
        this.response = response;
        notify();
    }

    public synchronized void setException(RuntimeException exception) {
        this.exception = exception;
        notify();
    }

    public synchronized Response getResponse() {
        while (response == null && exception == null) {
            try {
                wait();
            } catch (InterruptedException e) {
                LOG.error("wait (getResponse) interrupted", e);
            }
        }

        if (exception != null) {
            RuntimeException toThrow = exception;
            exception = null;
            throw toThrow;
        }

        Response r = response;
        response = null;
        notify();
        return r;
    }

}
// Copyright (c) Naked Objects Group Ltd.
